@@ -3,13 +3,13 @@ Jobs related client handler logic.
 
 Remember that in code snippets all highlighted lines are required other lines are optional.
 """
-from .base_client import BaseClient
+from .base_client import BaseClient, TagsSupportMixin
 from ..models import Artifact, Job
 from ..repositories.jobs import ListJobs, ListJobLogs, ListJobArtifacts, CreateJob, DeleteJob, StopJob, \
     DeleteJobArtifacts, GetJobArtifacts, GetJobMetrics, StreamJobMetrics
 
 
-class JobsClient(BaseClient):
+class JobsClient(TagsSupportMixin, BaseClient):
     """
     Client to handle job related actions.
 
@@ -172,7 +172,7 @@ class JobsClient(BaseClient):
         handle = repository.create(job, data=data)
 
         if tags:
-            self.add_tags(entity_id=handle, entity=self.entity, tags=tags)
+            self.add_tags(entity_id=handle, tags=tags)
 
         return handle
 
@@ -249,7 +249,7 @@ class JobsClient(BaseClient):
         )
         return jobs
 
-    def logs(self, job_id, line=0, limit=10000):
+    def logs(self, job_id, line=1, limit=10000):
         """
         Method to retrieve job logs.
 
@@ -271,10 +271,10 @@ class JobsClient(BaseClient):
         :rtype: list
         """
         repository = self.build_repository(ListJobLogs)
-        logs = repository.list(job_id=job_id, line=line, limit=limit)
+        logs = repository.list(id=job_id, line=line, limit=limit)
         return logs
 
-    def yield_logs(self, job_id, line=0, limit=10000):
+    def yield_logs(self, job_id, line=1, limit=10000):
         """Get log generator. Polls the API for new logs
 
         .. code-block:: python
@@ -296,7 +296,7 @@ class JobsClient(BaseClient):
         """
 
         repository = self.build_repository(ListJobLogs)
-        logs = repository.yield_logs(job_id=job_id, line=line, limit=limit)
+        logs = repository.yield_logs(id=job_id, line=line, limit=limit)
         return logs
 
     def artifacts_delete(self, job_id, files=None):
