@@ -9,6 +9,7 @@ from ..utils import concatenate_urls
 @attr.s
 class Notebook(object):
     id = attr.ib(type=str, default=None)
+    machine_type = attr.ib(type=str, default=None)
     vm_type_id = attr.ib(type=int, default=None)
     vm_type_label = attr.ib(type=str, default=None)
     container_id = attr.ib(type=int, default=None)
@@ -17,6 +18,7 @@ class Notebook(object):
     cluster_id = attr.ib(type=str, default=None)
     registry_username = attr.ib(type=str, default=None)
     registry_password = attr.ib(type=str, default=None)
+    command = attr.ib(type=str, default=None)
     default_entrypoint = attr.ib(type=str, default=None)
     container_user = attr.ib(type=str, default=None)
     shutdown_timeout = attr.ib(type=int, default=None)
@@ -57,6 +59,7 @@ class Notebook(object):
 @attr.s
 class NotebookStart(object):
     notebook_id = attr.ib(type=str, default=None)
+    machine_type = attr.ib(type=str, default=None)
     vm_type_id = attr.ib(type=int, default=None)
     vm_type_label = attr.ib(type=str, default=None)
     cluster_id = attr.ib(type=str, default=None)
