@@ -1,7 +1,7 @@
 import marshmallow as ma
 
-from gradient.api_sdk import models
 from .base import BaseSchema
+from .. import models
 
 
 class DeploymentSchema(BaseSchema):
@@ -36,6 +36,16 @@ class DeploymentSchema(BaseSchema):
     cluster_id = ma.fields.Str(dump_to="clusterId", load_from="clusterId")
     tags = ma.fields.List(ma.fields.Str(), load_only=True)
     command = ma.fields.Str()
+    metrics_url = ma.fields.Str(dump_to="metricsURL", load_from="metricsURL")
+    workspace_url = ma.fields.Str(dump_to="workspaceUrl", load_from="workspaceUrl")
+    workspace_ref = ma.fields.Str(dump_to="workspaceRef", load_from="workspaceRef")
+    workspace_username = ma.fields.Str(dump_to="workspaceUsername", load_from="workspaceUsername")
+    workspace_password = ma.fields.Str(dump_to="workspacePassword", load_from="workspacePassword")
+    dt_created = ma.fields.DateTime(dump_to="dtCreated", load_from="dtCreated")
+    dt_modified = ma.fields.DateTime(dump_to="dtModified", load_from="dtModified")
+    dt_started = ma.fields.DateTime(dump_to="dtStarted", load_from="dtStarted")
+    dt_stopped = ma.fields.DateTime(dump_to="dtStopped", load_from="dtStopped")
+    dt_deleted = ma.fields.DateTime(dump_to="dtDeleted", load_from="dtDeleted")
 
 
 class DeploymentCreateSchema(DeploymentSchema):
