@@ -4,7 +4,6 @@ import pydoc
 
 import six
 import terminaltables
-from click import style
 from halo import halo
 
 from gradient import api_sdk, exceptions, Job, JobArtifactsDownloader, cli_constants
@@ -157,24 +156,7 @@ class ListJobsCommand(BaseJobCommand):
 
 
 class JobLogsCommand(LogsCommandMixin, BaseJobCommand):
-    def _make_table(self, logs, id):
-        table_title = "Job %s logs" % id
-        table_data = [("LINE", "MESSAGE")]
-        table = terminaltables.AsciiTable(table_data, title=table_title)
-
-        for log in logs:
-            table_data.append(self._format_row(log))
-
-        return table.table
-
-    def _get_log_row_string(self, id, log):
-        log_msg = "{}\t{}".format(*self._format_row(log))
-        return log_msg
-
-    @staticmethod
-    def _format_row(log_row):
-        return (style(fg="red", text=str(log_row.line)),
-                log_row.message)
+    ENTITY = "Job"
 
 
 class CreateJobCommand(BaseCreateJobCommandMixin, BaseJobCommand):
